==> haskell-glob-0.9.2-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-glob.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Glob
version: 0.9.2
id: Glob-0.9.2-HJ6eAu8fFh08wRJGfeL7G1
key: Glob-0.9.2-HJ6eAu8fFh08wRJGfeL7G1
license: BSD-3-Clause
maintainer: Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author: Matti Niemenmaa
stability: provisional
homepage: http://iki.fi/matti.niemenmaa/glob/
synopsis: Globbing library
description:
    A library for globbing: matching patterns against file paths.
category: System
abi: 45e5e2356859721fffc205bcf8d3fea2
exposed: True
exposed-modules:
    System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules: System.FilePath.Glob.Base
                System.FilePath.Glob.Directory System.FilePath.Glob.Match
                System.FilePath.Glob.Simplify System.FilePath.Glob.Utils
import-dirs: /usr/lib/ghc-8.4.3/site-local/Glob-0.9.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/Glob-0.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/Glob-0.9.2
hs-libraries: HSGlob-0.9.2-HJ6eAu8fFh08wRJGfeL7G1
depends:
    base-4.11.1.0 containers-0.5.11.0 directory-1.3.1.5
    dlist-0.8.0.5-6LWFCfMSEKNIqqazR8mrr6 filepath-1.4.2
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             dlist-0.8.0.5-6LWFCfMSEKNIqqazR8mrr6=f0c6d817a8f4177a2d0e3837521bb503
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
haddock-interfaces: /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html: /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-glob-0.9.3-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-glob.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Glob
version: 0.9.3
id: Glob-0.9.3-EWfWGrcNvnJ8DspgY55ZzU
key: Glob-0.9.3-EWfWGrcNvnJ8DspgY55ZzU
license: BSD-3-Clause
maintainer: Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author: Matti Niemenmaa
stability: provisional
homepage: http://iki.fi/matti.niemenmaa/glob/
synopsis: Globbing library
description:
    A library for globbing: matching patterns against file paths.
category: System
abi: 7b0a0165fcbc107cec927754704dddde
exposed: True
exposed-modules:
    System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules: System.FilePath.Glob.Base
                System.FilePath.Glob.Directory System.FilePath.Glob.Match
                System.FilePath.Glob.Simplify System.FilePath.Glob.Utils
import-dirs: /usr/lib/ghc-8.4.3/site-local/Glob-0.9.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/Glob-0.9.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/Glob-0.9.3
hs-libraries: HSGlob-0.9.3-EWfWGrcNvnJ8DspgY55ZzU
depends:
    base-4.11.1.0 containers-0.5.11.0 directory-1.3.1.5
    dlist-0.8.0.5-6LWFCfMSEKNIqqazR8mrr6 filepath-1.4.2
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             dlist-0.8.0.5-6LWFCfMSEKNIqqazR8mrr6=f0c6d817a8f4177a2d0e3837521bb503
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
haddock-interfaces: /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html: /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
